diff OrthancServer/DicomProtocol/DicomUserConnection.cpp @ 62:a70bb32802ae orthanc-renaming

renaming Server
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:33:19 +0200
parents 4bc019d2f969
children b8dfde8d64e8
line wrap: on
line diff
--- a/OrthancServer/DicomProtocol/DicomUserConnection.cpp	Sun Sep 16 09:30:31 2012 +0200
+++ b/OrthancServer/DicomProtocol/DicomUserConnection.cpp	Sun Sep 16 09:33:19 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "DicomUserConnection.h"
 
-#include "../../Core/PalanthirException.h"
+#include "../../Core/OrthancException.h"
 #include "../ToDcmtkBridge.h"
 #include "../FromDcmtkBridge.h"
 
@@ -46,7 +46,7 @@
 #endif 
 
 
-namespace Palanthir
+namespace Orthanc
 {
   struct DicomUserConnection::PImpl
   {
@@ -70,7 +70,7 @@
   {
     if (cond.bad())
     {
-      throw PalanthirException("DicomUserConnection: " + std::string(cond.text()));
+      throw OrthancException("DicomUserConnection: " + std::string(cond.text()));
     }
   }
 
@@ -78,7 +78,7 @@
   {
     if (!IsOpen())
     {
-      throw PalanthirException("DicomUserConnection: First open the connection");
+      throw OrthancException("DicomUserConnection: First open the connection");
     }
   }
 
@@ -170,7 +170,7 @@
     DIC_UI sopInstance;
     if (!DU_findSOPClassAndInstanceInDataSet(dcmff.getDataset(), sopClass, sopInstance))
     {
-      throw PalanthirException("DicomUserConnection: Unable to find the SOP class and instance");
+      throw OrthancException("DicomUserConnection: Unable to find the SOP class and instance");
     }
 
     // Figure out which of the accepted presentation contexts should be used
@@ -180,7 +180,7 @@
       const char *modalityName = dcmSOPClassUIDToModality(sopClass);
       if (!modalityName) modalityName = dcmFindNameOfUID(sopClass);
       if (!modalityName) modalityName = "unknown SOP class";
-      throw PalanthirException("DicomUserConnection: No presentation context for modality " + 
+      throw OrthancException("DicomUserConnection: No presentation context for modality " + 
                               std::string(modalityName));
     }
 
@@ -306,14 +306,14 @@
       break;
 
     default:
-      throw PalanthirException(ErrorCode_ParameterOutOfRange);
+      throw OrthancException(ErrorCode_ParameterOutOfRange);
     }
 
     // Figure out which of the accepted presentation contexts should be used
     int presID = ASC_findAcceptedPresentationContextID(pimpl_->assoc_, sopClass);
     if (presID == 0)
     {
-      throw PalanthirException("DicomUserConnection: The C-FIND command is not supported by the distant AET");
+      throw OrthancException("DicomUserConnection: The C-FIND command is not supported by the distant AET");
     }
 
     T_DIMSE_C_FindRQ request;
@@ -403,7 +403,7 @@
     int presID = ASC_findAcceptedPresentationContextID(pimpl_->assoc_, sopClass);
     if (presID == 0)
     {
-      throw PalanthirException("DicomUserConnection: The C-MOVE command is not supported by the distant AET");
+      throw OrthancException("DicomUserConnection: The C-MOVE command is not supported by the distant AET");
     }
 
     T_DIMSE_C_MoveRQ request;
@@ -471,7 +471,7 @@
   {
     if (host.size() > HOST_NAME_MAX - 10)
     {
-      throw PalanthirException("Distant host name is too long");
+      throw OrthancException("Distant host name is too long");
     }
 
     Close();
@@ -519,7 +519,7 @@
 
     if (ASC_countAcceptedPresentationContexts(pimpl_->params_) == 0)
     {
-      throw PalanthirException("DicomUserConnection: No Acceptable Presentation Contexts");
+      throw OrthancException("DicomUserConnection: No Acceptable Presentation Contexts");
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium